@@ -17,12 +17,6 @@ allowed_bouton_categories = [
 
 class PresynapticBoutonType(ReferenceAnnotation):
 
-    target_id = mm.fields.Int(
-        required=True,
-        description="Synapse annotation id reference",
-        reference_type="synapse",
-    )
-
     bouton_type = mm.fields.Str(
         required=True,
         validate=OneOf(allowed_bouton_categories),
